Package: FaultTree
Version: 1.0.1
Date: 2023-8-26
Title: Fault Trees for Risk and Reliability Analysis
Authors@R: c(person("David", "Silkworth", email = "djsilk@openreliability.org", role = "aut"), person("Jacob", "Ormerod", email = "jake@openreliability.org", role = "cre"), person("OpenReliability.org", role = "cph"))
Description: Construction, calculation and display of fault trees. Methods derived from Clifton A. Ericson II (2005, ISBN: 9780471739425) <DOI:10.1002/0471739421>, Antoine Rauzy (1993) <DOI:10.1016/0951-8320(93)90060-C>, Tim Bedford and Roger Cooke (2012, ISBN: 9780511813597) <DOI:10.1017/CBO9780511813597>, Nikolaos Limnios,  (2007, ISBN: 9780470612484) <DOI: 10.1002/9780470612484>.
License: GPL (>= 3)
Copyright: copyright (c) OpenReliability.org 2015-2022
URL: http://www.openreliability.org/fault-tree-analysis-on-r/
LazyLoad: yes
Imports: Rcpp (>= 0.12.4)
LinkingTo: Rcpp, RcppArmadillo
Author: David Silkworth [aut],
  Jacob Ormerod [cre],
  OpenReliability.org [cph]
Maintainer: Jacob Ormerod <jake@openreliability.org>
NeedsCompilation: yes
Suggests: magrittr
Packaged: 2023-08-26 16:29:12 UTC; djs
Repository: CRAN
Date/Publication: 2023-08-26 17:00:05 UTC
Built: R 4.4.0; x86_64-apple-darwin21.6.0; 2024-05-07 23:00:02 UTC; unix
